@@ -4,7 +4,7 @@
 # may not use this file except in compliance with the License. A copy of
 # the License is located at
 #
-# http://aws.amazon.com/apache2.0/
+# http://www.apache.org/licenses/LICENSE-2.0
 #
 # or in the "license" file accompanying this file. This file is
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
@@ -35,7 +35,10 @@ LOGGER = logging.getLogger(__name__)
 def logout(verbose):
     """Log out of all AWS SSO sessions"""
     configure_logging(LOGGER, verbose)
-    session = botocore.session.Session()
+    session = botocore.session.Session(session_vars={
+        'profile': (None, None, None, None),
+        'region': (None, None, None, None),
+    })
 
     LOGGER.debug("Removing tokens")
     SSOTokenSweeper(session).delete_credentials(SSO_TOKEN_DIR)
